@@ -14,9 +14,9 @@
 /* Apply different normalization for 2 bit case      rjc 01.01.19       */
 /* Break out normalization code into separate func.  rjc 01.11.7        */
 /* apply delay offset by channel if non-zero         rjc 2011.8.10      */
+/* allow multiple seq. or combined polarizations     rjc 2011.12.21     */
 /*                                                                      */
 /*      Inputs:     pass        Contains various essential parameters   */
-/*                  pol         0,1,2,3 = LL,RR,LR,RL                   */
 /*                  fr          fourfit frequency channel number        */
 /*                  ap          Sequential AP number                    */
 /*                                                                      */
@@ -32,49 +32,79 @@
 #define TWO_32   4294967296.0
 #define SYSCLK_S 32.e6                  /* number of sysclks / sec */
 
-norm (pass, pol, fr, ap)
-struct type_pass *pass;
-int pol, fr, ap;
+norm (struct type_pass *pass, 
+      int fr, 
+      int ap)
     { 
     struct type_120 *rawdatum;
     struct freq_corel *fdata;
     struct data_corel *datum;
     int flagbit, sb, st, i, rev_i, j, l, m, intshift, ct, nlags;
     int cosbits, coscor, sinbits, sincor;
+    int ip, ips;
     complex xcor[4*MAXLAG], xp_spec[2*MAXLAG], S[4*MAXLAG];
     complex c_zero(), conju(), c_mult(), c_add(), c_exp(), s_mult();
+    complex z;
     double c_mag ();
     float  fraction, count_frac;
     unsigned short bitshift;
     double theta, shift, dd, norm_const, fb_fact, fb_amp_ratio();
     double samp_per_ap, corrfact, rawcorr, factor, mean;
-    double diff_delay, deltaf;
+    double diff_delay, deltaf, polcof;
     int flagmask,
         freq_no,
         ibegin,
-        sindex;
+        sindex,
+        pol,
+        npolpasses;
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L/X/H, 1:R/Y/V
     extern struct type_param param;
     extern struct type_status status;
 
-
-
+    if (param.pol == POL_ALL)
+        {
+        pol = pass->pol;                // single pol being done per pass
+        ips = pol;
+        }
+    else                                // linear combination of polarizations
+        ips = 0;
+                                        // for special case of Ixy mode we have the
+                                        // power for 2 polarizations, but make 4 passes
+    if (param.pol == POL_IXY)
+        npolpasses = 4;
+    else
+        npolpasses = pass->npols;
+        
     nlags = param.nlags;
     samp_per_ap = param.acc_period / param.samp_period;
+    freq_no = fcode(pass->pass_data[fr].freq_code);
 
                                         /* Point to current frequency */
     fdata = pass->pass_data + fr;
                                         /* Convenience pointer */
     datum = fdata->data + ap;
                                         /* Initialize */
-    for (i = 0; i < nlags*4; i++) S[i] = c_zero();
+    for (i = 0; i < nlags*4; i++)
+        S[i] = c_zero();
+        
     datum->sband = 0;
                                         /* -1.0 means no data, not zero weight */
     datum->usbfrac = -1.0;
     datum->lsbfrac = -1.0;
                                         /*  sideband # -->  0=upper , 1= lower */
     for (sb = 0; sb < 2; sb++) 
+      {
+      for (i = 0; i < nlags*4; i++)     // clear xcor & xp_spec for pol sum into them
+          {
+          xcor[i]=c_zero();
+          xp_spec[i] = c_zero();
+          }
+
+      for (ip=ips; ip<pass->pol+1; ip++) // loop over polarization products
         {
+        if (param.pol)
+            pol = ip;
+
         if (sb) 
             flagmask = LSB_FLAG << 2*pol;
         else
@@ -87,29 +117,41 @@ int pol, fr, ap;
         switch (pol)
             {
             case POL_LL: rawdatum = datum->apdata_ll[sb];
+                         polcof = (param.pol == POL_IXY) ?
+                             cos (param.par_angle[1] - param.par_angle[0]) :
+                             1.0;
                          break;
             case POL_RR: rawdatum = datum->apdata_rr[sb];
+                         polcof = (param.pol == POL_IXY) ?
+                             cos (param.par_angle[1] - param.par_angle[0]) :
+                             1.0;
                          break;
             case POL_LR: rawdatum = datum->apdata_lr[sb];
+                         polcof = (param.pol == POL_IXY) ?
+                             sin (param.par_angle[1] - param.par_angle[0]) :
+                             1.0;
                          break;
             case POL_RL: rawdatum = datum->apdata_rl[sb];
+                         polcof = (param.pol == POL_IXY) ?
+                            -sin (param.par_angle[1] - param.par_angle[0]) :
+                             1.0;
                          break;
             }
-                                        /* Keep track of sideband info */
-        if (sb) 
-            datum->sband -= 1; /* LSB */
-        else    
-            datum->sband += 1;
+                                        // Keep cumulative track of sideband info
+                                        // once per polarizaton
+        if (ip == pass->pol)
+            {
+            if (sb) 
+                datum->sband -= 1;      // LSB
+            else    
+                datum->sband += 1;      // USB
+            }
             
         if (param.corr_type == MK4HDW)
             {
                                         /* Calculate normalization quantities */
             calc_normalization (sb, pol, datum, pass, &mean, &norm_const);
         
-                                        /* Next, compute correlation coefficients */
-                                        /* 10,000 = 100% correlated */
-            for(i=0;i<nlags*4;i++)
-                xcor[i]=c_zero();
                                         /* Loop over lags 
                                          *  i source index for cross correlation 
                                          *  m    "     "    "  auto       "
@@ -175,16 +217,16 @@ int pol, fr, ap;
                     {
                     status.zero_errors++;
                     msg ("marking ap %d for a zero error", 0, ap);
-                                        /* mark this sideband & pol piece of this AP bad */
+                                        // mark this sideband & pol piece of this AP bad
                     datum->flag &= ~(1 << (2 * pol + sb));
-                    break;                  /* break out of loop over lags  */
+                    break;              // break out of loop over lags
                     }            
                                      
                 if ((cosbits < SLIVER) || ((sinbits < SLIVER) && (! pass->autocorr)))
                     {
                     status.sliver_errors++;
                     msg ("marking ap %d for a sliver error", 0, ap);
-                                        /* mark this sideband & pol piece of this AP bad */
+                                        // mark this sideband & pol piece of this AP bad
                     datum->flag &= ~(1 << (2 * pol + sb));
                     break;              /* break out of loop over lags  */
                     }
@@ -193,61 +235,80 @@ int pol, fr, ap;
                                          * 3 lower order bits in accumulator */
                                         /* Proper autocorrelation normalization is */
                                         /* lag-dependent, Need computation here */
-                xcor[l].re = norm_const * (8.0 * coscor - mean * cosbits) / cosbits;
-                if (pass->autocorr) xcor[l].im = 0.0;
+                z.re = norm_const * (8.0 * coscor - mean * cosbits) / cosbits;
+                if (pass->autocorr)
+                    z.im = 0.0;
                                         /* Conjugate if USB, not if LSB */
                 else if (sb == 0)
-                    xcor[l].im = -norm_const * (8.0 * sincor - mean * sinbits) / sinbits;
+                    z.im = -norm_const * (8.0 * sincor - mean * sinbits) / sinbits;
                 else if (sb == 1)
-                    xcor[l].im =  norm_const * (8.0 * sincor - mean * sinbits) / sinbits;
+                    z.im =  norm_const * (8.0 * sincor - mean * sinbits) / sinbits;
 
                                         /* Check for wild values, zero out and */
                                         /* flag for later accounting */
-                if ((xcor[l].re > param.cor_limit) || (xcor[l].re < -param.cor_limit) 
-                    || (xcor[l].im > param.cor_limit) || (xcor[l].im < -param.cor_limit)) 
+                if ((z.re > param.cor_limit) || (z.re < -param.cor_limit) 
+                    || (z.im > param.cor_limit) || (z.im < -param.cor_limit)) 
                     {
                     status.large_errors++;
                                         /* mark this sideband & pol piece of this AP bad */
                     datum->flag &= ~(1 << (2 * pol + sb));
                     break;                  /* break out of loop over lags  */
                     }
+                                        // apply pcal to data and add into xcor
+                                        // iff this is a requested pol product
+                if (param.pol & 1<<ip || param.pol == 0)
+                    {
+                    if (sb==0)
+                        z = c_mult (z, datum->pc_phasor[ip]);
+                    else                // use conjugate of usb pcal tone for lsb
+                        z = c_mult (z, conju (datum->pc_phasor[ip]));
+
+                    z = s_mult (z, polcof);
+
+                    xcor[l].re += z.re;
+                    xcor[l].im += z.im;
                                         /* Accumulate data fractions */
                                         /* Makes use of fact that cosbits */
                                         /* = sinbits for cross-corr */
-                if (sb) 
-                    {
-                    if (datum->lsbfrac < 0.0) datum->lsbfrac = 0.0;
-                    datum->lsbfrac += 
-                        (double)(cosbits)/(samp_per_ap * nlags);
+                    if (sb) 
+                        {
+                        if (datum->lsbfrac < 0.0) 
+                            datum->lsbfrac = 0.0;
+                        datum->lsbfrac += (double) (cosbits)
+                                        / (samp_per_ap * nlags * npolpasses);
+                        }
+                    else 
+                        {
+                        if (datum->usbfrac < 0.0) 
+                            datum->usbfrac = 0.0;
+                        datum->usbfrac += (double) (cosbits)
+                                        / (samp_per_ap * nlags * npolpasses);
+                        }
                     }
-                else 
-                    {
-                    if (datum->usbfrac < 0.0) datum->usbfrac = 0.0;
-                    datum->usbfrac += 
-                        (double)(cosbits)/(samp_per_ap * nlags);
-                    }
-                }                           /* end of loop over i (lags) */
+                }                       /* end of loop over i (lags) */
             
                                         /* In case large error zapped this datum ... */
             if ((datum->flag & (1 << (2 * pol + sb))) == 0)
                 {
                 msg ("skipping data for ap %d pol %d sb %d", -2, ap, pol, sb);
-                continue;                   /* skip over rest of the sideband loop */
+                continue;               /* skip over rest of the sideband loop */
                 }
-                                        /* Increment a.p. counts */
-                                        /* Integer counts ... */
-            (status.ap_num[sb][fr])++;
+                                        // only do frequency domain calculations once
+            if (ip != pass->pol)        // so check for last polarization in loop
+                continue;
+                                        // bump accumulation period counters
+            status.ap_num[sb][fr]++;
             status.total_ap++;
                                         /* Microedited counts */
             if (sb) 
                 {
                 status.ap_frac[sb][fr] += datum->lsbfrac;
-                status.total_ap_frac += datum->lsbfrac;
+                status.total_ap_frac   += datum->lsbfrac;
                 }
             else 
                 {
                 status.ap_frac[sb][fr] += datum->usbfrac;
-                status.total_ap_frac += datum->usbfrac;
+                status.total_ap_frac   += datum->usbfrac;
                 }
                                         /* Avg to find center of scan */
             status.epoch_off_cent += (double)ap;  
@@ -261,8 +322,8 @@ int pol, fr, ap;
                                         /* First, decode total bitshift shift */
             shift = fabs (rawdatum->delay_rate / TWO_32 * param.acc_period * SYSCLK_S);
                                         /* Get fractional part */
-            if (param.bocfs_per_ap % 2)     /* odd # of cf's/AP; must 
-                                           extrapolate fractional delay to cf center */
+            if (param.bocfs_per_ap % 2) // if odd # of cf's/AP must 
+                                        // extrapolate fractional delay to cf center
                 {
                 fraction = (rawdatum->fr_delay + 
                             0.5 * param.bocf_period * rawdatum->delay_rate) / TWO_32;
@@ -288,17 +349,16 @@ int pol, fr, ap;
                 dd = 0.5;
             else 
                 dd = -0.5;
-        // printf ("shift %lg intshift %d dd %lf fraction %f fr_delay %x delay_rate %x\r\n",
-        //          shift, intshift, dd, fraction, rawdatum->fr_delay, rawdatum->delay_rate);
                                         /* Convert to angle, avoid zero division */
-            if (shift == 0.0) shift = 1.0;
+            if (shift == 0.0) 
+                shift = 1.0;
 
                                         /* switched sign of theta  rjc 99.11.19 */
             theta = - M_PI / nlags * (fraction - dd) * (1 - intshift / shift);
 
-                                        // retroactive fix for non-zero values of delay and
-                                        // delay_rate coming from correlator in the case of
-                                        // an autocorrelation           rjc 2007.8.14
+                                        // retroactive fix for non-zero values of delay
+                                        // and delay_rate coming from correlator in the
+                                        // case of an autocorrelation      rjc 2007.8.14
             if (rawdatum->type == AUTO_GLOBAL || rawdatum->type == AUTO_PER_LAG)
                 {
                 fraction = 0.0;
@@ -308,8 +368,6 @@ int pol, fr, ap;
                                         /* Factor to correct AP amplitudes by */
                                         /* Maximum of +- 0.2% */
             fb_fact = fb_amp_ratio ((double) fraction, shift);
-
-        /* printf ("*** theta %lf fb_fact %lf sb %d nlags %d\r\n", theta, fb_fact, sb, nlags); */
             }
         else                            // difx (spectral) mode; just copy spectrum in
             {
@@ -319,151 +377,200 @@ int pol, fr, ap;
                 return;
                 }
             
-            status.ap_num[sb][fr]++;
-            status.total_ap++;
+            if (ip == pass->pol)
+                {                   // last included polarization, do totals
+                status.ap_num[sb][fr]++;
+                status.total_ap++;
+                                    // sum to micro-edited totals
+                if (sb) 
+                    {
+                    datum->lsbfrac = 1.0;
+                    status.ap_frac[sb][fr] += datum->lsbfrac / npolpasses;
+                    status.total_ap_frac   += datum->lsbfrac / npolpasses;
+                    }
+                else 
+                    {
+                    datum->usbfrac = 1.0;
+                    status.ap_frac[sb][fr] += datum->usbfrac / npolpasses;
+                    status.total_ap_frac   += datum->usbfrac / npolpasses;
+                    }
+                }
             fb_fact = 1.0;          // may want to re-examine this assumption
             theta = 0.0;            // no fractional bit induced error correction
 
-            if (sb) 
-                {
-                datum->lsbfrac = 1.0;
-                status.ap_frac[sb][fr] += datum->lsbfrac;
-                status.total_ap_frac += datum->lsbfrac;
-                }
-            else 
-                {
-                datum->usbfrac = 1.0;
-                status.ap_frac[sb][fr] += datum->usbfrac;
-                status.total_ap_frac += datum->usbfrac;
-                }
-
             for (i=0; i<nlags; i++)
                 {
-                xp_spec[i].re = rawdatum->ld.spec[i].re;
-                xp_spec[i].im = rawdatum->ld.spec[i].im;
                                     // filter out any nan's, if present
-                if (isnan (xp_spec[i].re) || isnan (xp_spec[i].im))
+                if (isnan (rawdatum->ld.spec[i].re) || isnan (rawdatum->ld.spec[i].im))
                     {
-                    msg ("clearing nan's in visibility for ap %d fr %d lag %i", 2, ap, fr, i);
-                    xp_spec[i].re = 0.0;
-                    xp_spec[i].im = 0.0;
+                    msg ("omitting nan's in visibility for ap %d fr %d lag %i", 2, ap, fr, i);
+                    }
+                                    // add in iff this is a requested pol product
+                else if (param.pol & 1<<ip || param.pol == 0)
+                    {           
+                    z.re = rawdatum->ld.spec[i].re;
+                    z.im = rawdatum->ld.spec[i].im;
+                                    // rotate each pol prod by pcal prior to adding in
+                    if (sb==0)
+                        z = c_mult (z, datum->pc_phasor[ip]);
+                    else                // use conjugate of usb pcal tone for lsb
+                        z = c_mult (z, conju (datum->pc_phasor[ip]));
+                                        // scale phasor by polarization coefficient
+                    z = s_mult (z, polcof);
+
+                                    // corrections to phase as fn of freq based upon 
+                                    // delay calibrations
+                                    // apply delay offset phase ramp
+                                    // iff the offset is non-zero
+                    diff_delay = pass->control.delay_offs[freq_no].rem 
+                               - pass->control.delay_offs[freq_no].ref;
+                                    // add in phase effects if multitone delays 
+                                    // were extracted
+                    if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
+                                                && param.pc_mode[1] == MULTITONE)      
+                        diff_delay += 1e9 * (datum->rem_sdata.mt_delay[stnpol[1][pol]] 
+                                           - datum->ref_sdata.mt_delay[stnpol[0][pol]]);
+                                    // apply only non-zero delay effects 
+                    if (diff_delay != 0.0)
+                        {
+                        msg ("ap %d fr %d diff_delay %f", -2, ap, fr, diff_delay);
+                                    // calculate offset frequency of DC edge in
+                                    // GHz from the reference frequency for USB
+                            deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
+                                    // refer phase ramp to actual midband
+                            if (datum->sband)
+                                deltaf -= 1e-3 * datum->sband / (4e6 * param.samp_period);
+                                    // apply phase ramp to spectral points 
+                            z = c_mult (z, c_exp (-2.0 * M_PI * diff_delay * deltaf));
+                        }
+                    xp_spec[i].re += z.re;
+                    xp_spec[i].im += z.im;
                     }
                 }
-            }
+            }                       // end of spectral mode code
+        }                           // bottom of polarization loop
 
-                                        /* apply spectral filter as needed */
-            apply_passband (sb, fdata, xp_spec, nlags*2);
+                                    /* apply spectral filter as needed */
+      apply_passband (sb, fdata, xp_spec, nlags*2);
 
-                                        /* Put sidebands together.  For each sb, */
-                                        /* the Xpower array, which is the FFT across */
-                                        /* lags, is symmetrical about DC of the */
-                                        /* sampled sideband, and thus contains the */
-                                        /* (filtered out) "other" sideband, which */
-                                        /* consists primarily of noise.  Thus we only */
-                                        /* copy in half of the Xpower array */
-                                        /* Weight each sideband by data fraction */
+                                    /* Put sidebands together.  For each sb,
+                                       the Xpower array, which is the FFT across
+                                       lags, is symmetrical about DC of the
+                                       sampled sideband, and thus contains the
+                                       (filtered out) "other" sideband, which
+                                       consists primarily of noise.  Thus we only
+                                       copy in half of the Xpower array
+                                       Weight each sideband by data fraction */
 
-                                        // skip 0th spectral pt if DC channel suppressed
-        ibegin = (pass->control.dc_block) ? 1 : 0;
-        if (sb == 0)
-            { 
-            for (i = ibegin; i < nlags; i++)
-                {
-                factor = fb_fact * datum->usbfrac;
-                S[i] = s_mult (c_mult (xp_spec[i], 
-                        c_exp (theta * (double)(i-nlags/2))),factor);
-                }
-            }
-        else                            /* LSB: conjugate, add phase offset */
-            {
-            for (i = ibegin; i < nlags; i++)
-                {
-                factor = fb_fact * datum->lsbfrac;
-                                        // DC goes into 1st element of the S array
-                sindex = i ? 4 * nlags - i : 0;
-                S[sindex] = s_mult (conju (c_mult (xp_spec[i], 
-                               c_exp (theta * (double)(i-nlags/2) 
-                             + status.lsb_phoff[0] - status.lsb_phoff[1]))),factor);
-                }
-            }
-        }       /* End sideband loop */
-                                        /* Normalize data fractions */
-                                        /* The resulting sbdelay functions which */
-                                        /* are attached to each AP from this point */
-                                        /* on reflect twice as much power in the */
-                                        /* double sideband case as in single sideband. */
-                                        /* The usbfrac and lsbfrac numbers determine */
-                                        /* a multiplicative weighting factor to be */
-                                        /* applied.  In the double sideband case, the */
-                                        /* factor of two is inherent in the data values */
-                                        /* and additional weighting should be done */
-                                        /* using the mean of usbfrac and lsbfrac */
+                                    // skip 0th spectral pt if DC channel suppressed
+      ibegin = (pass->control.dc_block) ? 1 : 0;
+      if (sb == 0)
+          { 
+          for (i = ibegin; i < nlags; i++)
+              {
+              factor = fb_fact * datum->usbfrac;
+              S[i] = s_mult (c_mult (xp_spec[i], 
+                      c_exp (theta * (double)(i-nlags/2))),factor);
+              }
+          }
+      else                          /* LSB: conjugate, add phase offset */
+          {
+          for (i = ibegin; i < nlags; i++)
+              {
+              factor = fb_fact * datum->lsbfrac;
+                                    // DC goes into 1st element of the S array
+              sindex = i ? 4 * nlags - i : 0;
+              S[sindex] = s_mult (conju (c_mult (xp_spec[i], 
+                             c_exp (theta * (double)(i-nlags/2) 
+                           + status.lsb_phoff[0] - status.lsb_phoff[1]))),factor);
+              }
+          }
+      }                             // bottom of sideband loop 
+
+                                    /* Normalize data fractions
+                                       The resulting sbdelay functions which
+                                       are attached to each AP from this point
+                                       on reflect twice as much power in the
+                                       double sideband case as in single sideband.
+                                       The usbfrac and lsbfrac numbers determine
+                                       a multiplicative weighting factor to be
+                                       applied.  In the double sideband case, the
+                                       factor of two is inherent in the data values
+                                       and additional weighting should be done
+                                       using the mean of usbfrac and lsbfrac */
     factor = 0.0;
-    if (datum->usbfrac >= 0.0) factor += datum->usbfrac;
-    if (datum->lsbfrac >= 0.0) factor += datum->lsbfrac;
-    if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) factor /= 2.0;
-    if (factor > 0.0) factor = 1.0 / factor;
+    if (datum->usbfrac >= 0.0)
+        factor += datum->usbfrac;
+    if (datum->lsbfrac >= 0.0)
+        factor += datum->lsbfrac;
+    if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) 
+        factor /= 2.0;
+    if (factor > 0.0)
+        factor = 1.0 / factor;
     msg ("usbfrac %1f lsbfrac %1f factor %1f", -2, datum->usbfrac, datum->lsbfrac, factor);
-    for (i=0; i<4*nlags; i++) S[i] = s_mult (S[i], factor);
+    for (i=0; i<4*nlags; i++) 
+        S[i] = s_mult (S[i], factor);
 
-#ifdef NORM_HACK_HOOK
-#warning "spectral hacking enabled -- see hook_norm.c"
-    NORM_HACK_HOOK;
-#endif /* NORM_HACK_HOOK */
-
-                                        // corrections to phase as fn of freq based upon 
-                                        // delay calibrations
-                                        // apply delay offset phase ramp
-                                        // iff the offset is non-zero
-    freq_no = fcode(pass->pass_data[fr].freq_code);
-    diff_delay = pass->control.delay_offs[freq_no].ref 
-               - pass->control.delay_offs[freq_no].rem;
-                                        // add in phase effects if multitone delays were extracted
-    if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
-                                && param.pc_mode[1] == MULTITONE)      
-        diff_delay += 1e9 * (datum->ref_sdata.mt_delay[stnpol[0][pol]] 
-                           - datum->rem_sdata.mt_delay[stnpol[1][pol]]);
-
-    if (diff_delay != 0.0)              // apply only non-zero delay effects
+                                    // corrections to phase as fn of freq based upon 
+                                    // delay calibrations
+                                    // apply delay offset phase ramp
+                                    // spectral version is done above
+    if (rawdatum -> type != SPECTRAL)
         {
-        for (i=1, j=4*nlags-1; i<nlags; i++, j--)
+        diff_delay = pass->control.delay_offs[freq_no].rem 
+                   - pass->control.delay_offs[freq_no].ref;
+                                    // add in phase effects if multitone delays 
+                                    // were extracted
+        if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
+                                    && param.pc_mode[1] == MULTITONE)      
+            diff_delay += 1e9 * (datum->rem_sdata.mt_delay[stnpol[1][pol]] 
+                               - datum->ref_sdata.mt_delay[stnpol[0][pol]]);
+
+        if (diff_delay != 0.0)      // apply only non-zero delay effects
             {
-                                        // calculate offset frequency of DC edge in
-                                        // GHz from the reference frequency for USB
-                                        // for now (2011.10.5) don't phase ref to the ref freq
-            deltaf = 1e-3 * (/* fdata->frequency - param.ref_freq */
-                           + i / (2e6 * param.samp_period * nlags));
-                                        // apply phase ramp to spectral points 
-            S[i] = c_mult (S[i], c_exp (2.0 * M_PI * diff_delay * deltaf));
-                                        // ditto for LSB
-            deltaf = 1e-3 * (/* fdata->frequency - param.ref_freq */
-                           - i / (2e6 * param.samp_period * nlags));
-            S[j] = c_mult (S[j], c_exp (2.0 * M_PI * diff_delay * deltaf));
+            msg ("ap %d fr %d diff_delay %f", -2, ap, fr, diff_delay);
+            for (i=1, j=4*nlags-1; i<nlags; i++, j--)
+                {
+                                    // calculate offset frequency of DC edge in
+                                    // GHz from the reference frequency for USB
+                deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
+                if (datum->sband)       // refer phase ramp to actual midband
+                    deltaf -= 1e-3 * datum->sband / (4e6 * param.samp_period);
+                                    // apply phase ramp to spectral points 
+                S[i] = c_mult (S[i], c_exp (-2.0 * M_PI * diff_delay * deltaf));
+                                    // ditto for LSB
+                deltaf = 1e-3 * i / (2e6 * param.samp_period * nlags);
+                if (datum->sband)   // refer phase ramp to actual midband
+                    deltaf += 1e-3 * datum->sband / (4e6 * param.samp_period);
+                S[j] = c_mult (S[j], c_exp (2.0 * M_PI * diff_delay * deltaf));
+                }
             }
         }
-                                        /* Collect the results */
+                                    /* Collect the results */
     if(datum->flag != 0)
         {
-                                        /* FFT to single-band delay */
+                                    /* FFT to single-band delay */
         FFT1 (S, nlags*4, 1, xcor, 1);
-                                        /* Place SB delay values in data structure */
+                                    /* Place SB delay values in data structure */
         for (i = 0; i < nlags*2; i++)
             {
-                                        /* Translate so i=nlags is central lag */
+                                    /* Translate so i=nlags is central lag */
             j = i - nlags;
-            if (j < 0) j += nlags*4;
-                                        /* re-normalize back to single lag */
-                                        /* (property of FFTs) */
-                                        // nlags-1 norm. iff zeroed-out DC
+            if (j < 0) 
+                j += nlags*4;
+                                    /* re-normalize back to single lag */
+                                    /* (property of FFTs) */
+                                    // nlags-1 norm. iff zeroed-out DC
             if (pass->control.dc_block)
                 datum->sbdelay[i] = s_mult (xcor[j], 1.0 / (nlags - 1.0));
             else
                 datum->sbdelay[i] = s_mult (xcor[j], 1.0 / nlags);
             }
          }
-                                        /* No data */
+                                    /* No data */
     else
-        for (i = 0; i < nlags*2; i++) datum->sbdelay[i] = c_zero();
+        for (i = 0; i < nlags*2; i++) 
+            datum->sbdelay[i] = c_zero();
     }
 
 
@@ -482,11 +589,11 @@ double f,r;
            f2,r2,fact;
 double pi2 = 9.869604401;
 
-    f2 = f * f;                          /* pre-calculate useful factors */
+    f2 = f * f;                     // pre-calculate useful factors
     r2 = r * r;
 
     fp1 = (int) floor (f + r / 2 + 0.5);
-    fp2 = fp1 * fp1;          /* name is floor of expression, with plus sign, to 2nd power */
+    fp2 = fp1 * fp1;                // named by <floor><sign><power>
     fp3 = fp1 * fp2;
 
     fm1 = (int) floor (f - r / 2 + 0.5);
